@@ -13,6 +13,11 @@ import aws_cdk.aws_kms
 import aws_cdk.core
 import aws_cdk.cx_api
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ssm", "1.34.0", __name__[0:-6], "aws-ssm@1.34.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
